@@ -1,56 +1,74 @@
 ## File Name: IRT.modelfit.R
-## File Version: 0.10
-## File Last Change: 2017-01-31 14:07:28
+## File Version: 0.14
 
 ###########################################################
-IRT.modelfit <- function (object, ...) {
-    UseMethod("IRT.modelfit")
-       }
+IRT.modelfit <- function (object, ...)
+{
+	UseMethod("IRT.modelfit")
+}
 ###########################################################
 # general model fit function for CDM objects
-IRT.modelfit.CDM <- function( object , mod ){
-    res <- modelfit.cor.din( dinobj = object)
+IRT.modelfit.CDM <- function( object , mod )
+{
+	res <- modelfit.cor.din( dinobj = object)
 	res$IRT.IC <- IRT.IC(object)
 	res$objname <- mod
 	class(res) <- paste0("IRT.modelfit." , class(object) )
 	return(res)
-		}
+}
 ###########################################################
 
 
 ###########################################################
 # IRT.modelfit for objects of class din, gdina
-IRT.modelfit.din <- function( object , ... ){
-    cl <- paste(match.call())[2]	
-    res <- IRT.modelfit.CDM( object , mod=cl )
+IRT.modelfit.din <- function( object , ... )
+{
+	cl <- paste(match.call())[2]	
+	res <- IRT.modelfit.CDM( object , mod=cl )
 	return(res)	
-						}
+}
 #####################################################
-# IRT.modelfit for gdina objects						
-IRT.modelfit.gdina <- function( object , ... ){
-    cl <- paste(match.call())[2]	
-    res <- IRT.modelfit.CDM( object , mod=cl )
-	return(res)	
-						}						
-#############################################################						
+# IRT.modelfit for gdina objects
+IRT.modelfit.gdina <- function( object , ... )
+{
+	cl <- paste(match.call())[2]	
+	res <- IRT.modelfit.CDM( object , mod=cl )
+	return(res)
+}
+#############################################################
 
+#####################################################
+# IRT.modelfit for gdm objects
+IRT.modelfit.gdm <- function( object , ... )
+{
+	cl <- paste(match.call())[2]	
+	res <- IRT.modelfit.CDM( object , mod=cl )
+	return(res)	
+}
+#############################################################		
 
 ############################################################
 # summary
-summary.IRT.modelfit.helper <- function( object , ... ){	
+summary.IRT.modelfit.helper <- function( object , ... )
+{
 	cat("Test of Global Model Fit\n")
 	obji <- object$modelfit.test
-	for (vv in seq(2,ncol(obji))){	obji[,vv] <- round( obji[,vv] , 3 ) }
+	for (vv in seq(2,ncol(obji))){
+		obji[,vv] <- round( obji[,vv] , 3 )
+	}
 	print(obji)
 	cat("\nFit Statistics\n")
 	obji <- object$modelfit.stat
-	for (vv in seq(1,ncol(obji))){	obji[,vv] <- round( obji[,vv] , 3 ) }
-	print(obji)		
-		}
+	for (vv in seq(1,ncol(obji))){
+		obji[,vv] <- round( obji[,vv] , 3 )
+	}
+	print(obji)	
+}
 #################################################################	
 
 
 # summary.modelfit.cor.din 
 summary.IRT.modelfit.din <- summary.IRT.modelfit.helper
 summary.IRT.modelfit.gdina <- summary.IRT.modelfit.helper
+summary.IRT.modelfit.gdm <- summary.IRT.modelfit.helper
 # summary.IRT.modelfit.gdm <- summary.modelfit.cor.gdm
