@@ -1,11 +1,11 @@
 ## File Name: attach_environment.R
-## File Version: 0.01
-## File Last Change: 2017-06-14 18:46:01
+## File Version: 0.02
 
 
 #######################################
 # attach all elements in an environment   
-attach_environment <- function( res , envir ){
+attach_environment <- function( res , envir )
+{
 	CC <- length(res)
 	for (cc in 1:CC){
 		assign( names(res)[cc] , res[[cc]] , envir=envir )		
