@@ -1,6 +1,5 @@
 ## File Name: gdina.R
-## File Version: 9.115
-## File Last Change: 2017-09-18 15:51:36
+## File Version: 9.238
 
 
 ################################################################################
@@ -21,12 +20,16 @@ gdina <- function( data, q.matrix, skillclasses=NULL , conv.crit = 0.0001,
 					delta.basispar.init = NULL , 
 					zeroprob.skillclasses = NULL , 
 					attr.prob.init = NULL , 
-					reduced.skillspace=TRUE , 
+					reduced.skillspace=NULL , 
 					reduced.skillspace.method=2 , 
 					HOGDINA = -1 , 
 					Z.skillspace = NULL , 
-                    weights = rep( 1, nrow( data ) ),  rule = "GDINA", 
-                    progress = TRUE , 
+					weights = rep( 1, nrow( data ) ),  rule = "GDINA", 
+					regular_lam = 0, regular_type = "none", 
+					regular_alpha = NA, regular_tau=NA, 
+					mono.constr = FALSE, 
+					prior_intercepts = NULL, prior_slopes = NULL, 
+					progress = TRUE , 
 					progress.item = FALSE , 
 					mstep_iter = 10 ,
 					mstep_conv = 1E-4 , 
@@ -36,10 +39,13 @@ gdina <- function( data, q.matrix, skillclasses=NULL , conv.crit = 0.0001,
 					avoid.zeroprobs = FALSE , 
 					seed = 0 , 		
 					save.devmin=TRUE , calc.se = TRUE ,
-					se_version = 1 , 
+					se_version = 1 , PEM = TRUE , PEM_itermax = maxit , 
+					cd = FALSE, cd_steps = 1 , mono_maxiter = 10,
+					freq_weights=FALSE, 
 					...
-						){
-                    
+						)
+{
+
 # data: a required matrix of binary response data, whereas the items are in the columns 
 #       and the response pattern in the rows. NA values are allowed.
 #
@@ -78,7 +84,7 @@ gdina <- function( data, q.matrix, skillclasses=NULL , conv.crit = 0.0001,
 		d1 <- packageDescription("CDM")
 		cat( paste( d1$Package , " " , d1$Version , " (" , d1$Date , ")" , sep="") , "\n" )		
 	}
-    time1 <- list( "s1" = Sys.time() )
+	time1 <- list( "s1" = Sys.time() )
 	cl <- match.call()
 
 	#########################################################
@@ -93,7 +99,7 @@ gdina <- function( data, q.matrix, skillclasses=NULL , conv.crit = 0.0001,
 	#########################################################
 	# in case of item parameter noninvariance restructure dataset
 	#########################################################
-
+	
 	res <- gdina_proc_noninvariance_multiple_groups( data=data, q.matrix=q.matrix, 
 				invariance=invariance, group=group )
 	data <- res$data
@@ -132,7 +138,7 @@ gdina <- function( data, q.matrix, skillclasses=NULL , conv.crit = 0.0001,
 	################################################################################
 
 	r1 <- "GDINA Model"
-
+	
 	################################################################################
 	# multiple group estimation
 	################################################################################
@@ -146,6 +152,7 @@ gdina <- function( data, q.matrix, skillclasses=NULL , conv.crit = 0.0001,
 	group2 <- res$group2
 																	
 	#---- parameters for HOGDINA model
+	tetrachoric <- NULL
 	if (HOGDINA >= 0){	
 		res <- gdina_proc_hogdina_theta_distribution(G=G)	
 		theta.k <- res$theta.k
@@ -157,7 +164,7 @@ gdina <- function( data, q.matrix, skillclasses=NULL , conv.crit = 0.0001,
 	# display on R console                                                         #
 	################################################################################
 
-    disp <- r1      
+	disp <- r1      
 	s1 <- Sys.time()
 	#--- display progress
 	res <- gdina_progress_start_estimation( progress=progress, linkfct=linkfct, disp=disp, 
@@ -183,28 +190,29 @@ gdina <- function( data, q.matrix, skillclasses=NULL , conv.crit = 0.0001,
 	################################################################################
 	# Initialization and missing data handling                                     #
 	################################################################################
-    
-    # recode missing data by 9
-    resp <- 1 - is.na(dat.items)
-    dat.items[ resp == 0 ] <- 9
-    
-    #--- standardize weights such that the sum of defined weights is equal to the number of rows in the data frame
-    weights <- gdina_standardize_weights( weights=weights )
+
+	# recode missing data by 9
+	resp <- 1 - is.na(dat.items)
+	dat.items[ resp == 0 ] <- 9
+
+	#--- standardize weights such that the sum of defined weights is equal to the number of rows in the data frame
+	weights <- gdina_standardize_weights( weights=weights )
 		
 	################################################################################
 	# calculate item response patterns                                             #
 	################################################################################
 
-	res <- gdina_proc_item_response_patterns( dat.items=dat.items, J=J, G=G, weights=weights, group=group ) 
+	res <- gdina_proc_item_response_patterns( dat.items=dat.items, J=J, G=G, weights=weights, 
+					group=group, freq_weights=freq_weights ) 
 	item.patt.subj <- res$item.patt.subj
 	item.patt <- res$item.patt
 	six <- res$six
 	item.patt.freq <- res$item.patt.freq
-		 		 
+
 	################################################################################ 
 	# generate all attribute patterns                                              #
 	################################################################################
-
+	
 	res <- gdina_create_attribute_patterns( q.matrix=q.matrix, skillclasses=skillclasses, 
 				zeroprob.skillclasses=zeroprob.skillclasses, Z.skillspace=Z.skillspace, 
 				G=G, reduced.skillspace=reduced.skillspace ) 
@@ -223,11 +231,12 @@ gdina <- function( data, q.matrix, skillclasses=NULL , conv.crit = 0.0001,
 	
 	if ( reduced.skillspace ){
 		res <- gdina_attribute_patterns_reduced_skillspace( attr.patt=attr.patt, K=K, maxAttr=maxAttr, q.matrix=q.matrix, 
-					Z.skillspace=Z.skillspace ) 
+					Z.skillspace=Z.skillspace, G=G ) 
 		Z <- res$Z
 		ncolZ <- res$ncolZ
+		beta <- res$beta
 	}
-			
+
 	################################################################################
 	# assign uniform prior distribution of all latent class patterns                
 	################################################################################
@@ -239,7 +248,8 @@ gdina <- function( data, q.matrix, skillclasses=NULL , conv.crit = 0.0001,
 	# create design matrices 
 	################################################################################	
 
-	res <- gdina_create_designmatrices( J=J, Mj=Mj, Aj=Aj, q.matrix=q.matrix, rule=rule, L=L, attr.patt=attr.patt ) 
+	res <- gdina_create_designmatrices( J=J, Mj=Mj, Aj=Aj, q.matrix=q.matrix, rule=rule, L=L, attr.patt=attr.patt,
+				mono.constr=mono.constr) 
 	Mj <- res$Mj
 	Mj.userdefined <- res$Mj.userdefined
 	Aj <- res$Aj
@@ -249,11 +259,12 @@ gdina <- function( data, q.matrix, skillclasses=NULL , conv.crit = 0.0001,
 	attr.items <- res$attr.items
 	aggr.patt.designmatrix <- res$aggr.patt.designmatrix
 	Mj.index <- res$Mj.index	
+	Aj_mono_constraints <- res$Aj_mono_constraints
 	
 	###############################################################################
 	# initial item parameters
 	###############################################################################
-	
+
 	delta <- gdina_init_item_parameters( delta.init=delta.init, linkfct=linkfct, J=J, seed=seed, Mj=Mj, 
 				delta.basispar.init=delta.basispar.init, delta.designmatrix=delta.designmatrix, Mj.index=Mj.index,
 				rule=rule ) 
@@ -261,75 +272,134 @@ gdina <- function( data, q.matrix, skillclasses=NULL , conv.crit = 0.0001,
 	#------ some compute inverse matrices for least squares estimation
 	invM.list <- gdina_proc_uls_inverse_matrices(Mj=Mj, J=J)
 
- 	if ( fac.oldxsi>= 1){ 
+	if ( fac.oldxsi>= 1){
 		fac.oldxsi <- 0 
 	}
 	djj_old <- as.list( 1:J )
-				
+
 	################################################################################
 	# some prelimaries for EM algorithm                                            #  
 	################################################################################
 
-	res <- gdina_proc_split_item_response_patterns( item.patt=item.patt, J=J )         
+	res <- gdina_proc_split_item_response_patterns( item.patt=item.patt, J=J,
+					freq_weights = freq_weights, resp=resp, dat.items=dat.items)         
 	IP <- res$IP
 	resp.patt <- res$resp.patt
 	item.patt.split <- res$item.patt.split	
-   
-    iter <- 1 # Iteration number
-    likediff <- 1 # Difference in likelihood estimates
-    loglike <- 0 # init for log-Likelihood
-    
-    # init value for maximum parameter change in likelihood maximization
-    max.par.change <- 1000
-    devchange <- 1000
+
+	iter <- 1 # Iteration number
+	likediff <- 1 # Difference in likelihood estimates
+	opt_fct <- loglike <- 0 # init for log-Likelihood
+
+	# init value for maximum parameter change in likelihood maximization
+	max.par.change <- 1000
+	devchange <- 1000
 	
 	# analyze response patterns if there are some missings
 	cmresp <- colMeans( resp.patt )
-    some.missings <- mean(cmresp) < 1
+	some.missings <- mean(cmresp) < 1
 	
-    # calculations for expected counts
+	# calculations for expected counts
 	# response indicator list
-    resp.ind.list <- list( 1:J )
+	resp.ind.list <- list( 1:J )
 	for (i in 1:J){ 
 		resp.ind.list[[i]] <- which( resp.patt[,i] == 1)  
 	}
-	
+
 	# this matrix ipr is needed for computing R.lj
 	if (G==1){
 		ipr <- item.patt.split * item.patt.freq*resp.patt
 	}
-       
-    disp <- "...........................................................\n"		
+
+	disp <- "...........................................................\n"		
 
 	#** for reduced skillspace
 	if (reduced.skillspace){
-		item_patt_freq_matr <- outer( item.patt.freq , rep( 1 , L) )	
+		if (G==1){
+			item_patt_freq_matr <- cdm_matrix1( item.patt.freq , ncol=L )	
+		} else {
+			item_patt_freq_matr <- array( NA, dim=c(nrow(item.patt.freq), L, G ) )
+			for (gg in 1:G){
+				item_patt_freq_matr[,,gg] <- cdm_matrix1( item.patt.freq[,gg] , ncol=L )	
+			}
+		}
 	}
-    
+
+	#--- delta parameter indices
+	res <- gdina_proc_delta_indices(delta=delta, Mj=Mj)
+	delta_indices <- res$delta_indices
+	delta_partable <- res$delta_partable
+	delta_vec <- unlist(delta)
+
+	# reconvert vector into a list
+	delta <- gdina_delta_convert_into_list( delta_vec=delta_vec, delta_indices=delta_indices, J=J ) 
+
+	#-- preliminaries PEM acceleration
+	if (PEM){	
+		envir <- environment()	
+		if (! reduced.skillspace){
+			pem_pars <- c("delta_vec","attr.prob")
+		}
+		if (reduced.skillspace){
+			pem_pars <- c("delta_vec","beta")
+		}
+		if (HOGDINA > 0){ PEM <- FALSE }
+		pem_output_vars <- unique( c( pem_pars , "delta.new","attr.prob") )
+		parmlist <- cdm_pem_inits_assign_parmlist(pem_pars=pem_pars, envir=envir)
+		res <- cdm_pem_inits( parmlist=parmlist)
+		pem_parameter_index <- res$pem_parameter_index
+		pem_parameter_sequence <- res$pem_parameter_sequence				
+	}
+
+	deviance.history <- rep(NA, maxit)
+	
+	#------------------------------
+	# choose regularization, coordinate descent and monotonicity constraints
+	res <- gdina_proc_regularization( regular_type=regular_type, cd=cd, mono.constr=mono.constr, linkfct=linkfct, 
+					method=method, PEM=PEM, regular_alpha=regular_alpha, regular_tau=regular_tau ) 
+	linkfct <- res$linkfct
+	save.devmin <- res$save.devmin
+	method <- res$method
+	regularization <- res$regularization
+	cd_algorithm <- res$cd_algorithm
+	PEM <- res$PEM
+	regular_alpha <- res$regular_alpha
+	regular_tau <- res$regular_tau
+	regularization_types <- res$regularization_types
+
+	#--------- process prior distributions
+	res <- gdina_proc_prior_distribution( prior_intercepts=prior_intercepts, prior_slopes=prior_slopes, method=method, 
+					linkfct=linkfct, PEM=PEM ) 
+	prior_intercepts <- res$prior_intercepts
+	prior_slopes <- res$prior_slopes
+	linkfct <- res$linkfct
+	method <- res$method
+	use_prior <- res$use_prior	
+	PEM <- res$PEM
+	
 	#********************************
 	# extract parameters with minimal deviances
 
-    dev.min <- 1E99
+	dev.min <- 1E99
 	R.lj.gg <- I.lj.gg <- NULL
 	suffstat_probs <- as.list(1:J)
-		
+
 	devchange <- 0	
 	#*********************************
 
 	################################################################################
 	# BEGIN OF THE ITERATION LOOP                                                  #
 	################################################################################
-    
-    while ( ( iter <= maxit ) & 
-				( ( max.par.change > conv.crit ) | ( devchange > dev.crit  ) )	)
-	{
 
+	while ( ( iter <= maxit ) & ( ( max.par.change > conv.crit ) | ( devchange > dev.crit  ) ) )
+	{
+		
 		################################################################################
 		# STEP I:                                                                      #
 		# calculate P(X_i | alpha_l):                                                  # 
 		# probability of each item response pattern given an attribute pattern         #
 		################################################################################
-	
+
 		#--- calculate item response probabilities
 		pjM <- gdina_calc_prob( progress=progress, iter=iter, disp=disp, J=J, L=L, 
 					aggr.attr.patt=aggr.attr.patt, Mj=Mj, delta=delta, linkfct=linkfct ) 
@@ -352,28 +422,28 @@ gdina <- function( data, q.matrix, skillclasses=NULL , conv.crit = 0.0001,
 		#######################################################################
 		# STEP II0: higher order GDINA model
 		#######################################################################
-		
+
 		if (HOGDINA >= 0){
 			res <- gdina_attribute_structure_hogdina( G=G, attr.prob=attr.prob, attr.patt=attr.patt, 
-						wgt.theta=wgt.theta, HOGDINA=HOGDINA, a.attr=a.attr, b.attr=b.attr, theta.k=theta.k ) 
+						wgt.theta=wgt.theta, HOGDINA=HOGDINA, a.attr=a.attr, b.attr=b.attr, theta.k=theta.k,
+						tetrachoric=tetrachoric ) 
 			a.attr <- res$a.attr
 			b.attr <- res$b.attr
 			attr.prob <- res$attr.prob
+			tetrachoric <- res$tetrachoric	
 		}
 		
 		#######################################################################
 		# STEP IIa: reduction of skill space					
 		#######################################################################
-
-		# This currently only works in case of a single group
-		if (reduced.skillspace){			
-			ntheta <- colSums( item_patt_freq_matr*p.aj.xi )
-			res <- gdina_reduced_skillspace( ntheta=ntheta, Z=Z, reduced.skillspace.method=reduced.skillspace.method )
+		
+		if (reduced.skillspace){
+			res <- gdina_reduced_skillspace_multiple_groups( Z=Z, reduced.skillspace.method=reduced.skillspace.method, 
+						item_patt_freq_matr=item_patt_freq_matr, p.aj.xi=p.aj.xi, G=G ) 
 			beta <- res$beta
 			attr.prob <- res$attr.prob
-			pred.ntheta <- res$pred.ntheta
 		}
-		 
+		
 		################################################################################
 		# STEP III:                                                                    #
 		# calculate I_{lj} and R_{lj}                                                  #
@@ -392,37 +462,79 @@ gdina <- function( data, q.matrix, skillclasses=NULL , conv.crit = 0.0001,
 		R.lj <- res$R.lj
 		I.lj.gg <- res$I.lj.gg
 		R.lj.gg <- res$R.lj.gg
-			
+		
 		################################################################################
 		# STEP IV:                                                                     #
 		# M Step																	   # 
 		# GDINA Model																   #
 		################################################################################
-
+		
 		res <- gdina_mstep_item_parameters( R.lj=R.lj, I.lj=I.lj, aggr.patt.designmatrix=aggr.patt.designmatrix, 
-					max.increment=max.increment, increment.factor=increment.factor, J=J, Aj=Aj, Mj=Mj, delta=delta, 
-					method=method, avoid.zeroprobs=avoid.zeroprobs, invM.list=invM.list, linkfct=linkfct, rule=rule, 
-					iter=iter, fac.oldxsi=fac.oldxsi, rrum.model=rrum.model, delta.fixed=delta.fixed, devchange=devchange, 
-					mstep_iter=mstep_iter, mstep_conv=mstep_conv, Mj.index=Mj.index, suffstat_probs=suffstat_probs ) 	
+						max.increment=max.increment, increment.factor=increment.factor, J=J, Aj=Aj, Mj=Mj, 
+						delta=delta, method=method, avoid.zeroprobs=avoid.zeroprobs, invM.list=invM.list, 
+						linkfct=linkfct, rule=rule, iter=iter, fac.oldxsi=fac.oldxsi, rrum.model=rrum.model, 
+						delta.fixed=delta.fixed, devchange=devchange, mstep_iter=mstep_iter, 
+						mstep_conv=mstep_conv, Mj.index=Mj.index, suffstat_probs=suffstat_probs, 
+						regular_lam=regular_lam, regular_type=regular_type, cd_steps=cd_steps, 
+						mono.constr=mono.constr, Aj_mono_constraints=Aj_mono_constraints, 
+						mono_maxiter=mono_maxiter, regular_alpha=regular_alpha, regular_tau=regular_tau, 
+						regularization_types=regularization_types, prior_intercepts=prior_intercepts, 
+						prior_slopes=prior_slopes, use_prior=use_prior )
 		delta.new <- res$delta.new
 		suffstat_probs <- res$suffstat_probs
-	
+		mono_constraints_fitted <- res$mono_constraints_fitted
+		penalty <- res$penalty
+		ll_value <- res$ll_value
+		logprior_value <- res$logprior_value
+
 		##########################################################################
 		# estimation with a design matrix for delta parameters
 		##########################################################################
 		if ( ! is.null( delta.designmatrix ) ){ 
-			delta.new <- gdina_mstep_item_parameters_designmatrix( delta.new=delta.new, delta.designmatrix=delta.designmatrix, 
+			delta.new <- gdina_mstep_item_parameters_designmatrix( delta.new=delta.new, 
+								delta.designmatrix=delta.designmatrix, 
 								delta.basispar.lower=delta.basispar.lower, 
 								delta.basispar.upper=delta.basispar.upper, Mj.index=Mj.index , J=J) 		
 		}
-									
+
+		delta_vec <- unlist(delta.new)
+
+		#-- PEM acceleration
+		if (PEM){
+			#-- collect all parameters in a list
+			parmlist <- cdm_pem_inits_assign_parmlist(pem_pars=pem_pars, envir=envir)			
+			#-- define log-likelihood function
+			ll_fct <- gdina_calc_loglikelihood
+			#- extract parameters
+			ll_args <- list( delta_vec=delta_vec, beta=beta, attr.prob=attr.prob, Z=Z, delta_indices=delta_indices, J=J, 
+					iter=iter, disp=disp, L=L, aggr.attr.patt=aggr.attr.patt, Mj=Mj, linkfct=linkfct, IP=IP, 
+					item.patt.split=item.patt.split, resp.ind.list=resp.ind.list, 
+					zeroprob.skillclasses=zeroprob.skillclasses, item.patt.freq=item.patt.freq, 
+					loglike=loglike, G=G, reduced.skillspace=reduced.skillspace ) 
+			#-- apply general acceleration function (take care of the correct iteration index:
+			#    it must start at zero)
+			res <- cdm_pem_acceleration( iter=iter-1, pem_parameter_index=pem_parameter_index, 
+						pem_parameter_sequence=pem_parameter_sequence, pem_pars=pem_pars, 
+						PEM_itermax=PEM_itermax, parmlist=parmlist, ll_fct=ll_fct, ll_args=ll_args,
+						deviance.history=deviance.history )
+			#-- collect output					
+			PEM <- res$PEM
+			pem_parameter_sequence <- res$pem_parameter_sequence
+			cdm_pem_acceleration_assign_output_parameters( res_ll_fct=res$res_ll_fct, 
+							vars=pem_output_vars , envir=envir, update=res$pem_update ) 			
+		}			
+		
+		
 		#################################################
 
 		#--- calculate deviance
 		res <- gdina_calc_deviance( p.xi.aj=p.xi.aj, attr.prob=attr.prob, item.patt.freq=item.patt.freq, 
-					loglike=loglike, G=G, IP=IP ) 
+					loglike=loglike, G=G, IP=IP, regularization=regularization, penalty=penalty,
+					opt_fct=opt_fct, logprior_value=logprior_value) 
 		like.new <- res$like.new
 		likediff <- res$likediff
+		opt_fct <- res$opt_fct
+		opt_fct_change <- res$opt_fct_change
 		loglikeold <- loglike
 		loglike <- like.new
 		
@@ -432,13 +544,18 @@ gdina <- function( data, q.matrix, skillclasses=NULL , conv.crit = 0.0001,
 	
 		#--- progress EM algorithm
 		res <- gdina_progress_em_algorithm( delta=delta, data=data, like.new=like.new, loglikeold=loglikeold, 
-					max.par.change=max.par.change, iter=iter, progress=progress, progress.item=progress.item ) 
+					max.par.change=max.par.change, iter=iter, progress=progress, 
+					progress.item=progress.item, regularization=regularization, penalty=penalty, 
+					opt_fct=opt_fct, opt_fct_change=opt_fct_change, ll_value=ll_value,
+					regular_type = regular_type, logprior_value=logprior_value, use_prior=use_prior ) 
+
 		utils::flush.console() # Output is flushing on the console
 		iter <- iter + 1 # new iteration number                                    
 		devchange <- abs( 2*(like.new-loglikeold) )
-   	
+
 		#**** update parameters at minimal deviance
-		dev <- -2*like.new		
+		dev <- -2*like.new	
+		deviance.history[iter-1] <- dev		
 		if (save.devmin){		
 			if ( dev < dev.min ){
 				iter.min <- iter-1	
@@ -452,6 +569,9 @@ gdina <- function( data, q.matrix, skillclasses=NULL , conv.crit = 0.0001,
 				loglike.min <- loglike
 			}		
 		}
+		if ( ! save.devmin ){
+			iter.min <- iter
+		}
 		#********************************
 		
 	}	
@@ -472,7 +592,7 @@ gdina <- function( data, q.matrix, skillclasses=NULL , conv.crit = 0.0001,
 		I.lj.min -> I.lj		
 		attr.prob.min -> attr.prob
 		loglike.min -> loglike		
-		}
+	}
 	#****************************************
 
 	#--- pattern output
@@ -507,17 +627,25 @@ gdina <- function( data, q.matrix, skillclasses=NULL , conv.crit = 0.0001,
 	attr.prob <- res$attr.prob
 	skill.patt <- res$skill.patt
 	
-	#------- calculation of the AIC und BIC        
+	#--- monotonicity boundaries and regularized parameters
+	res <- gdina_postproc_regularized_constrained_parameters( mono.constr=mono.constr, delta=delta, 
+					Aj_mono_constraints=Aj_mono_constraints, Mj=Mj, linkfct=linkfct, regularization=regularization,
+					data=data ) 
+	numb_bound_mono <- res$numb_bound_mono
+	numb_regular_pars <- res$numb_regular_pars
+	item_bound_mono <- res$item_bound_mono
+	
+	#--- calculation of the AIC und BIC        
 	res <- gdina_calc_ic( delta=delta, delta.designmatrix=delta.designmatrix, delta.fixed=delta.fixed, 
 				G=G, ncolZ=ncolZ, K=K, HOGDINA=HOGDINA, item.patt.freq=item.patt.freq, 
-				zeroprob.skillclasses=zeroprob.skillclasses, loglike=loglike )
+				zeroprob.skillclasses=zeroprob.skillclasses, loglike=loglike, numb_regular_pars=numb_regular_pars )
 	Npars <- res$Npars
 	aic <- res$aic
 	bic <- res$bic
 	caic <- res$caic
 	Nskillpar <- res$Nskillpar
 	Nipar <- res$Nipar	
-	
+
 	#--- postprocess posterior distributions	
 	res <- gdina_post_posterior_output( G=G, p.aj.xi=p.aj.xi, p.xi.aj=p.xi.aj, pattern=pattern, data=data, 
 				item.patt.subj=item.patt.subj, item.patt=item.patt, attr.prob=attr.prob, group=group ) 
@@ -526,8 +654,9 @@ gdina <- function( data, q.matrix, skillclasses=NULL , conv.crit = 0.0001,
 	p.xi.aj <- res$p.xi.aj
 	posterior <- res$posterior
 	pattern <- res$pattern
-	attr.prob0 <- res$attr.prob0	
-				
+	attr.prob0 <- res$attr.prob0
+	attr_prob <- res$attr_prob
+	
 	#--- item fit [ items , theta , categories ] 
 	res <- gdina_itemfit( L=L, J=J, R.lj=R.lj, I.lj=I.lj, item.patt.freq=item.patt.freq, G=G, 
 				attr.prob=attr.prob, data=data, pjM=pjM ) 
@@ -544,32 +673,45 @@ gdina <- function( data, q.matrix, skillclasses=NULL , conv.crit = 0.0001,
 	if (progress){
 		cat("---------------------------------------------------------------------------------\n")
 	}
+	
 	iter <- iterused
-    res <- list( coef=delta.summary, item=delta.summary, delta=delta, se.delta=se.delta, 
-			    probitem=probitem, itemfit.rmsea=itemfit.rmsea, mean.rmsea=mean(itemfit.rmsea),	
+	res <- list( coef=delta.summary, item=delta.summary, delta=delta, se.delta=se.delta, 
+				probitem=probitem, itemfit.rmsea=itemfit.rmsea, mean.rmsea=mean(itemfit.rmsea),	
 				loglike=loglike, deviance=-2*loglike, G=G, N=colSums( as.matrix(item.patt.freq) ), 
 				AIC=aic, BIC=bic, CAIC=caic, Npars =Npars, Nipar=Nipar , Nskillpar=Nskillpar,
 				Nskillclasses=L, varmat.delta=varmat.delta, varmat.palj=varmat.palj,
-                posterior=posterior, like=p.xi.aj, data=data, q.matrix=q.matrix,
-                pattern=pattern, attribute.patt=attr.prob, skill.patt=skill.patt,
-                subj.pattern=item.patt.subj, attribute.patt.splitted=attr.patt, 
+				posterior=posterior, like=p.xi.aj, data=data, q.matrix=q.matrix,
+				pattern=pattern, attribute.patt=attr.prob, skill.patt=skill.patt,
+				attr.prob=attr_prob,
+				subj.pattern=item.patt.subj, attribute.patt.splitted=attr.patt, 
 				pjk=pjM,  Mj=Mj, Aj=Aj, rule=rule, linkfct=linkfct, delta.designmatrix=delta.designmatrix, 
 				reduced.skillspace=reduced.skillspace, Z.skillspace=if(reduced.skillspace){ Z } else { NULL }, 
 				beta=beta, covbeta=covbeta, display=disp, item.patt.split=item.patt.split, 
+				resp.ind.list=resp.ind.list, dat=item.patt.split, 
 				item.patt.freq=item.patt.freq, model.type=r1, iter=iter, iterused=iterused, rrum.model=rrum.model,
 				rrum.params= rrum.params, group.stat=group.stat,  NAttr=maxAttr, invariance=invariance, 
-				HOGDINA=HOGDINA, seed= seed, iter=iter, converged=iter < maxit )
-		 
+				HOGDINA=HOGDINA, mono.constr=mono.constr, regularization=regularization, regular_lam=regular_lam,
+				regular_alpha=regular_alpha, regular_tau=regular_tau ,
+				numb_bound_mono=numb_bound_mono, item_bound_mono=item_bound_mono, numb_regular_pars=numb_regular_pars, 
+				regular_type=regular_type, cd_algorithm=cd_algorithm, cd_steps=cd_steps, 
+				prior_intercepts=prior_intercepts, prior_slopes=prior_slopes, use_prior = use_prior, 
+				logprior_value=logprior_value, 	
+				seed= seed, iter=iter, converged=iter < maxit , iter.min=iter.min, 
+				deviance.history=deviance.history, penalty=penalty, opt_fct=opt_fct )
+
 	if (HOGDINA>=0) { 
-	    colnames(a.attr) <- paste0( "a.Gr" , 1:G )
+		colnames(a.attr) <- paste0( "a.Gr" , 1:G )
 		colnames(b.attr) <- paste0( "b.Gr" , 1:G )
-		rownames(b.attr) <- rownames(a.attr) <- colnames(q.matrix)
+		int.attr <- - b.attr / a.attr
+		colnames(int.attr) <- paste0( "int.Gr" , 1:G )
+		rownames(int.attr) <- rownames(b.attr) <- rownames(a.attr) <- colnames(q.matrix)
 		res$a.attr <- a.attr 
 		res$b.attr <- b.attr
-		res$attr.rf <- cbind( b.attr , a.attr )
-	}						
+		res$int.attr <- int.attr
+		res$attr.rf <- cbind( b.attr , a.attr, int.attr )
+	}
 	# computation time
-    time1$s2 <- Sys.time()
+	time1$s2 <- Sys.time()
 	res$time <- time1
 	# res$time$timediff <- print(res$time$s2 - res$time$s1)	
 	res$time$timediff <- res$time$s2 - res$time$s1	
@@ -581,27 +723,25 @@ gdina <- function( data, q.matrix, skillclasses=NULL , conv.crit = 0.0001,
 	control <- list( skillclasses=skillclasses, q.matrix=q.matrix, conv.crit=conv.crit, 
 					dev.crit=dev.crit, maxit=maxit, linkfct=linkfct, Mj=Mj, Aj=Aj, 
 					group=group, method=method, delta.designmatrix=delta.designmatrix, 
-					delta.basispar.lower=delta.basispar.lower, delta.basispar.upper=delta.basispar.upper, 					
+					delta.basispar.lower=delta.basispar.lower, delta.basispar.upper=delta.basispar.upper,
 					delta.basispar.init=delta.basispar.init, zeroprob.skillclasses=zeroprob.skillclasses, 
 					reduced.skillspace=reduced.skillspace, HOGDINA=HOGDINA, Z.skillspace=Z.skillspace, 
-                    weights=weights, rule=rule, I.lj=I.lj, R.lj=R.lj, I.lj.gg=I.lj.gg, 
+					weights=weights, rule=rule, I.lj=I.lj, R.lj=R.lj, I.lj.gg=I.lj.gg, 
 					R.lj.gg=R.lj.gg, aggr.patt.designmatrix=aggr.patt.designmatrix,	Mj.index=Mj.index, method=method,
 					aggr.attr.patt=aggr.attr.patt,IP=IP, p.aj.xi=p.aj.xi,item.patt.split=item.patt.split,
 					resp.patt=resp.patt,freq.pattern=freq.pattern, item.patt.freq=item.patt.freq,invM.list=invM.list,
-					item.patt.subj=item.patt.subj, item.patt=item.patt, suffstat_probs=suffstat_probs, 					
+					item.patt.subj=item.patt.subj, item.patt=item.patt, suffstat_probs=suffstat_probs, 
 					increment.factor=increment.factor, fac.oldxsi=fac.oldxsi, avoid.zeroprobs=avoid.zeroprobs,
 					attr.prob=attr.prob0, delta.fixed=delta.fixed, sequential=sequential,
 					invariance=invariance, se_version=se_version ) 	
 	res$control <- control			
-    #--- create parameter table	
+	#--- create parameter table	
 	res$partable <- gdina_partable(res)	
 	#--- polychoric correlations
 	res$polychor <- CDM.calc.polychor(res)	
 	res$call <- cl
-    class(res) <- "gdina"
-    return(res)
+	class(res) <- "gdina"
+	return(res)
 }
 ##################################################################
 
-
-
