@@ -1,9 +1,8 @@
 ## File Name: gdina_attribute_patterns_reduced_skillspace.R
-## File Version: 0.02
-## File Last Change: 2017-06-17 14:01:50
+## File Version: 0.05
 
 gdina_attribute_patterns_reduced_skillspace <- function( attr.patt, K, maxAttr, q.matrix,
-		Z.skillspace )
+		Z.skillspace, G )
 {
 	A <- attr.patt
 	# combinations
@@ -13,24 +12,28 @@ gdina_attribute_patterns_reduced_skillspace <- function( attr.patt, K, maxAttr,
 	for (kk in 1:KK){
 		B <- cbind( B , attr.patt[ , kombis[1,kk] ] * attr.patt[ , kombis[2,kk] ] )
 	}
-    Z <- cbind( 1 , A , B )
+	Z <- cbind( 1 , A , B )
 	ncolZ <- ncol(Z)
-    v1 <- c("Int" ,  paste("A",1:K , sep="") ) 		 
+	v1 <- c("Int" ,  paste("A",1:K , sep="") ) 		 
 	v1 <- c(v1,apply( kombis , 2 , FUN = function(ll){ 
 			paste( paste( "A" , ll , sep="") , collapse="_" ) } ))
 	colnames(Z) <- v1	
 	
 	m1 <- which( maxAttr > 1 )
 	if ( max(maxAttr) > 1 ){
-	   Z1 <- Z[ , m1 , drop=FALSE ]^2
-	   colnames(Z1) <- paste0( colnames(q.matrix)[m1] , "*2")
-	   Z <- cbind( Z , Z1 )
+		Z1 <- Z[ , m1 , drop=FALSE ]^2
+		colnames(Z1) <- paste0( colnames(q.matrix)[m1] , "*2")
+		Z <- cbind( Z , Z1 )
 	}
 	if ( ! is.null(Z.skillspace) ){ 
 		Z <- Z.skillspace
 	}
 	ncolZ <- ncol(Z)
+	beta <- rep(0, ncolZ )
+	if (G > 1){
+		beta <- matrix( beta , nrow=ncolZ, ncol=G)
+	}
 	#----- OUTPUT
-	res <- list(Z=Z, ncolZ=ncolZ )
+	res <- list(Z=Z, ncolZ=ncolZ, beta=beta )
 	return(res)
 }
