@@ -1,8 +1,7 @@
 ## File Name: gdina_create_designmatrices.R
-## File Version: 0.01
-## File Last Change: 2017-06-05 12:38:10
+## File Version: 0.06
 
-gdina_create_designmatrices <- function( J, Mj, Aj, q.matrix, rule, L, attr.patt )
+gdina_create_designmatrices <- function( J, Mj, Aj, q.matrix, rule, L, attr.patt, mono.constr )
 {
 	Mj.userdefined <- TRUE
 	if ( is.null(Mj) ){ 
@@ -11,6 +10,7 @@ gdina_create_designmatrices <- function( J, Mj, Aj, q.matrix, rule, L, attr.patt
 	}
 	# Notation for Mj and Aj follows De La Torre (2011)
 	Aj <- NULL
+	Aj_mono_constraints <- NULL
 	Nattr.items <- rowSums(q.matrix >= 1)
 	# list of necessary attributes per item
 	necc.attr <- as.list( rep(NA,J) )
@@ -24,23 +24,27 @@ gdina_create_designmatrices <- function( J, Mj, Aj, q.matrix, rule, L, attr.patt
 			stop( paste("Q matrix row " , jj , " has only zero entries\n" , sep="") ) 
 		}	
 		Aj1 <- Aj[[jj]] <- .create.Aj( Nattr.items[jj] )
+		#--- define monotonicity constraints
+		if (mono.constr){
+			Aj_mono_constraints[[jj]] <- gdina_create_designmatrices_monotonicity_constraints(Ajjj=Aj[[jj]] )
+		}
 		if ( ! Mj.userdefined ){ 
 			Mj[[jj]] <- .create.Mj( Aj[[jj]] , rule = rule[jj] )	
 		}
- 		l1 <- as.list( 1 )
+		l1 <- as.list( 1 )
 		l2 <- rep(0,L)	
 		for (zz in seq(1,nrow(Aj1)) ){  # begin row zz
- 			Aj1zz <- outer( rep(1,nrow(attr.patt)) , Aj1[zz,] )
+			Aj1zz <- outer( rep(1,nrow(attr.patt)) , Aj1[zz,] )
 			apzz <- attr.patt[ , nj1 ]
 			apzz <- 1 * ( apzz >= q.matrix[ rep(jj,L) ,nj1] )
 			l1[[zz]] <- which( rowMeans( apzz == Aj1zz  ) == 1)
 			l2[ l1[[zz]] ] <- zz
 		}   # end row zz
 		attr.items[[jj]] <- l1
-		aggr.attr.patt[[jj]] <- l2		
+		aggr.attr.patt[[jj]] <- l2
 	}	# end item jj
 
-    #******						
+	#******
 	# indices for Mj
 	Mj.index <- matrix( 0 , J , 6 )
 	for (jj in 1:J){
@@ -50,19 +54,19 @@ gdina_create_designmatrices <- function( J, Mj, Aj, q.matrix, rule, L, attr.patt
 	Mj.index[,3] <- cumsum( Mj.index[,1] )
 	Mj.index[,2] <- c(1,Mj.index[-J,3] + 1 )
 	Mj.index[,6] <- cumsum( Mj.index[,4] )	
-	Mj.index[,5] <- c(1,Mj.index[-J,6] + 1 )	
+	Mj.index[,5] <- c(1,Mj.index[-J,6] + 1 )
 	# compute designmatrix of aggregation of pattern
 	aggr.patt.designmatrix <- matrix( 0 , L , max(Mj.index[,6]) )
 	for (jj in 1:J){
 		Mj.index.jj <- Mj.index[jj,]
 		for (vv in seq(1,Mj.index.jj[4]) ){
 			aggr.patt.designmatrix[ , Mj.index.jj[5] - 1 + vv ] <- 1  * ( aggr.attr.patt[[jj]] == vv )
-		}				
+		}
 	}
 	
 	#--- OUTPUT
 	res <- list(Mj=Mj, Mj.userdefined=Mj.userdefined, Aj=Aj, Nattr.items=Nattr.items, necc.attr=necc.attr,
 				aggr.attr.patt=aggr.attr.patt, attr.items=attr.items, aggr.patt.designmatrix=aggr.patt.designmatrix,
-				Mj.index=Mj.index )
+				Mj.index=Mj.index, Aj_mono_constraints=Aj_mono_constraints )
 	return(res)
 }
