@@ -1,6 +1,5 @@
 ## File Name: gdina_itemfit.R
 ## File Version: 0.01
-## File Last Change: 2017-06-05 15:17:44
 
 gdina_itemfit <- function( L, J, R.lj, I.lj, item.patt.freq , G , attr.prob, data, pjM )
 {
@@ -22,7 +21,7 @@ gdina_itemfit <- function( L, J, R.lj, I.lj, item.patt.freq , G , attr.prob, dat
 		pi.k[,1] <- attr.prob$class.prob
 	} 
 	probs <- aperm( pjM , c(3,1,2) )
-	itemfit.rmsea <- itemfit.rmsea( n.ik , pi.k , probs )$rmsea	
+	itemfit.rmsea <- itemfit.rmsea( n.ik=n.ik, pi.k=pi.k, probs=probs )$rmsea	
 	names(itemfit.rmsea) <- colnames(data)
 	#--- OUTPUT
 	res <- list( itemfit.rmsea=itemfit.rmsea, pi.k=pi.k, n.ik=n.ik, pi.k=pi.k)
