@@ -1,6 +1,5 @@
 ## File Name: gdm_calc_ic.R
-## File Version: 0.02
-## File Last Change: 2017-06-12 14:54:16
+## File Version: 0.05
 
 
 #############################################################
@@ -8,9 +7,9 @@
 gdm_calc_ic <- function( dev , dat , G ,  skillspace , irtmodel , 
 			K,D,TD,I,b.constraint,a.constraint , mean.constraint ,
 			Sigma.constraint , delta.designmatrix , standardized.latent ,
-			data0 , centerslopes , TP , centerintercepts )
+			data0 , centerslopes , TP , centerintercepts, centered.latent )
 {
-    ic <- list( "deviance" = dev , "n" = nrow(data0) )
+	ic <- list( "deviance" = dev , "n" = nrow(data0) )
 	ic$traitpars <- 0
 	ic$itempars <- 0	
 	#******
@@ -19,9 +18,12 @@ gdm_calc_ic <- function( dev , dat , G ,  skillspace , irtmodel ,
 	if ( skillspace == "normal" ){
 		if (irtmodel=="1PL" & ( D==1 )){
 			ic$traitpars <- 2*(G-1)	+ 1
-		}														
+		}
 		if ( ( irtmodel %in% c("2PL","2PLcat") ) & (D==1) ){
 			ic$traitpars <- 2*(G-1)
+			if (!standardized.latent){
+				ic$traitpars <- ic$traitpars + 2
+			}
 		}	
 		if (D > 1 ){
 			ic$traitpars <- 2 * D*G + D*(D-1)/2*G
@@ -31,8 +33,9 @@ gdm_calc_ic <- function( dev , dat , G ,  skillspace , irtmodel ,
 			if ( ! is.null(Sigma.constraint) ){ 
 					ic$traitpars <- ic$traitpars - nrow(Sigma.constraint)			
 			}
-		}														
+		}
 	}	# end normal
+
 	#******
 	# trait parameters: loglinear skillspace
 	if ( skillspace == "loglinear" ){
@@ -50,13 +53,14 @@ gdm_calc_ic <- function( dev , dat , G ,  skillspace , irtmodel ,
 	if ( ! is.null(b.constraint)){
 		ic$itempars.b <- ic$itempars.b - nrow(b.constraint)
 	}	
+
 	#************************************************
 	# item parameters a
 	ic$itempars.a <- 0
 	if ( irtmodel == "2PL"){ 
 		ic$itempars.a <- I*TD
 		if ( ! is.null(a.constraint)){
-			a.constraint2 <- a.constraint[ a.constraint[,3] == 1 , ]
+			a.constraint2 <- a.constraint[ a.constraint[,3] == 1 , , drop=FALSE]
 			ic$itempars.a <- ic$itempars.a - nrow(a.constraint2)
 		}	
 	}
@@ -72,15 +76,16 @@ gdm_calc_ic <- function( dev , dat , G ,  skillspace , irtmodel ,
 	# information criteria
 	ic$itempars <- ic$itempars.a + ic$itempars.b - ic$centeredintercepts - ic$centeredslopes
 	ic$np <- ic$itempars + ic$traitpars	
+	
 	# AIC
-    ic$AIC <- dev + 2*ic$np
-    # BIC
-    ic$BIC <- dev + ( log(ic$n) )*ic$np
-    # CAIC (conistent AIC)
-    ic$CAIC <- dev + ( log(ic$n) + 1 )*ic$np
+	ic$AIC <- dev + 2*ic$np
+	# BIC
+	ic$BIC <- dev + ( log(ic$n) )*ic$np
+	# CAIC (conistent AIC)
+	ic$CAIC <- dev + ( log(ic$n) + 1 )*ic$np
 	# corrected AIC
-    ic$AICc <- ic$AIC + 2*ic$np * ( ic$np + 1 ) / ( ic$n - ic$np - 1 )				
-    return(ic)
+	ic$AICc <- ic$AIC + 2*ic$np * ( ic$np + 1 ) / ( ic$n - ic$np - 1 )				
+	return(ic)
 }
 ###################################################################
 		
