@@ -1,6 +1,5 @@
 ## File Name: gdm_person_parameters.R
-## File Version: 0.01
-## File Last Change: 2017-06-12 14:54:28
+## File Version: 0.02
 
 
 
@@ -11,9 +10,9 @@ gdm_person_parameters <- function( data , D , theta.k ,
 {
 	#**************************
 	person <- data.frame("case" = 1:(nrow(data)) , "M" = rowMeans( data , na.rm=T)  )
-    EAP.rel <- rep(0,D)
-    names(EAP.rel) <- colnames(theta.k)
-    nstudl <- rep(1,nrow(data))
+	EAP.rel <- rep(0,D)
+	names(EAP.rel) <- colnames(theta.k)
+	nstudl <- rep(1,nrow(data))
 	doeap <- TRUE
 	if ( is.list( p.aj.xi)){	
 		p.aj.xi <- p.aj.xi[[1]] 
@@ -27,11 +26,12 @@ gdm_person_parameters <- function( data , D , theta.k ,
 			dd1 <- colnames(theta.k)[dd]
 			person$EAP <- rowSums( p.aj.xi * outer( nstudl , theta.k[,dd] ) )
 			person$SE.EAP <- sqrt(rowSums( p.aj.xi * outer( nstudl , theta.k[,dd]^2 ) ) - person$EAP^2)	
-			EAP.variance <- stats::weighted.mean( person$EAP^2 , weights ) - ( stats::weighted.mean( person$EAP , weights ) )^2
+			EAP.variance <- stats::weighted.mean( person$EAP^2 , weights ) - 
+								( stats::weighted.mean( person$EAP , weights ) )^2
 			EAP.error <- stats::weighted.mean( person$SE.EAP^2 , weights )
 			EAP.rel[dd] <- EAP.variance / ( EAP.variance + EAP.error )	
 			colnames(person)[ which( colnames(person) == "EAP" ) ] <- paste("EAP." , dd1 , sep="")
-			colnames(person)[ which( colnames(person) == "SE.EAP" ) ] <- paste("SE.EAP." , dd1 , sep="")				
+			colnames(person)[ which( colnames(person) == "SE.EAP" ) ] <- paste("SE.EAP." , dd1 , sep="")
 		}
 		# MLE	
 		mle.est <- theta.k[ max.col( p.xi.aj ) , , drop=FALSE]
