@@ -1,37 +1,27 @@
 ## File Name: modelfit.cor.din.R
-## File Version: 2.11
-## File Last Change: 2017-01-31 14:07:29
+## File Version: 2.13
 
 #############################################################
 # Model fit for din object
-modelfit.cor.din <- function( dinobj , jkunits = 0 ){
-    mod <- dinobj
+modelfit.cor.din <- function( dinobj , jkunits = 0 )
+{
+	mod <- dinobj
 	
 	# classes din and gdm
 	if ( class(dinobj) %in% c("din","gdina") ){
 		data <- as.matrix( mod$data )
 		posterior <- mod$posterior
 		probs <- mod$pjk
-				}
+	}
 	# class gdm
-    if (class(mod) == "gdm"){
+	if (class(mod) == "gdm"){
 		jkunits <- 0
 		probs <- aperm( mod$pjk , c(2,3,1) )
 		posterior <- mod$posterior
 		data <- as.matrix(mod$data)
-			}
-##			
-##   R>  print( str (probs)) 
-##    num [1:12, 1:2, 1:6] 0.816 0.722 0.749 0.788 0.847 ...
-##   [ items , categ , skills ]
-##
-##   R>  print( str (posterior)) 
-##    num [1:1000, 1:6] 0.986 0.9 0.986 0.986 0.88 ...
-##  [ persons , skills ]
-#    res <- modelfit.cor( data , posterior , probs )
-
- 
-    res <- modelfit.cor2( data , posterior , probs ) 
+	}
+	
+	res <- modelfit.cor2( data , posterior , probs ) 
 
 	#******************************************
 	# Jackknife
@@ -45,9 +35,9 @@ modelfit.cor.din <- function( dinobj , jkunits = 0 ){
 		c1 <- dinobj$control  
 		N <- nrow(data)		
 		if ( length(jkunits) == 1){
-		    jkunits <- min( N , jkunits )
+			jkunits <- min( N , jkunits )
 			jkunits <- floor( jkunits  * ( 1:N ) / (N+1) ) + 1
-							}
+		}
 		JJ <- length( unique( jkunits ) )
 		jkunits <- match( jkunits , unique(jkunits ) )
 		ms <- res$modelfit.stat
@@ -58,10 +48,8 @@ modelfit.cor.din <- function( dinobj , jkunits = 0 ){
 		progressbar_init <- diff( floor( 20 * ( 1:JJ ) / (JJ+1) ) + 1  )
 		progressbar_init <- c(20-sum(progressbar_init), progressbar_init )
 		for (jj in 1:JJ){
-	#		jj <- 1
 			data.jj <- data[ jkunits != jj , ]
 			weights.jj <- weights[ jkunits != jj ]  
-		#print( paste0("Iteration" , jj ) )			
 			#****
 			# DINA/DINO model			
 			if (class(dinobj)=="din"){
@@ -77,7 +65,7 @@ modelfit.cor.din <- function( dinobj , jkunits = 0 ){
 							wgtest.overrelax = c1$wgtest.overrelax , 
 							param.history = FALSE , 
 							progress = FALSE )
-													}
+			}
 			#****
 			# GDINA model
 			if (class(dinobj)=="gdina"){
@@ -90,22 +78,19 @@ modelfit.cor.din <- function( dinobj , jkunits = 0 ){
 						delta.designmatrix = c1$delta.designmatrix , 
 						delta.basispar.lower = c1$delta.basispar.lower , 
 						delta.basispar.upper = c1$delta.basispar.upper , 					
-#						delta.basispar.init = unlist(dinobj$delta)  , 
 						zeroprob.skillclasses = c1$zeroprob.skillclasses , 
 						reduced.skillspace= c1$reduced.skillspace , 
 						HOGDINA = c1$HOGDINA , 
 						Z.skillspace = c1$Z.skillspace , 
 						weights = weights.jj ,  rule = c1$rule , 
 						progress = FALSE ,	progress.item = FALSE )			
-					}						
+			}
 			#*** evaluate model fit
-#			f1jj <- modelfit.cor( data=mod.jj$data , posterior=mod.jj$posterior , 
-#							probs=mod.jj$pjk )		
 			f1jj <- modelfit.cor2( data=mod.jj$data , posterior=mod.jj$posterior , 
 							probs=mod.jj$pjk )									
 			ms.jack[,jj] <- f1jj$modelfit.stat[,1]
 			if ( progressbar_init[jj] == 1 ){ cat("-") ; utils::flush.console() }
-					}
+		}
 		cat("|\n")
 		res$modelfit.stat.jack <- ms.jack
 		# pseudo values
@@ -120,14 +105,15 @@ modelfit.cor.din <- function( dinobj , jkunits = 0 ){
 		ms$est_low <- ms$jk_est - 1.96 * ms$jk_se
 		ms$est_upp <- ms$jk_est + 1.96 * ms$jk_se
 		res$modelfit.stat <- ms	
-			}
+	}
 	###**** output
 	class(res) <- "modelfit.cor.din"
 	return(res)	
-                        }
+}
 ##############################################################
 # summary
-summary.modelfit.cor.din <- function( object , ... ){	
+summary.modelfit.cor.din <- function( object , ... )
+{	
 	cat("Test of Global Model Fit\n")
 	obji <- object$modelfit.test
 	for (vv in seq(2,ncol(obji))){	obji[,vv] <- round( obji[,vv] , 3 ) }
@@ -136,6 +122,6 @@ summary.modelfit.cor.din <- function( object , ... ){
 	obji <- object$modelfit.stat
 	for (vv in seq(1,ncol(obji))){	obji[,vv] <- round( obji[,vv] , 3 ) }
 	print(obji)		
-		}
+}
 #################################################################	
 
