@@ -1,12 +1,12 @@
 ## File Name: rrum.param.R
-## File Version: 0.02
-## File Last Change: 2017-01-31 14:07:29
+## File Version: 0.04
 
 
 
 #***************************************************************
 # RRUM parametrization
-.rrum.param <- function( delta.summary , q.matrix ){
+.rrum.param <- function( delta.summary , q.matrix )
+{
 	#---
 	#  RRUM parametrization
 	#  log( P(X=1) ) = b0 + b1*alpha1 + b2 * alpha2 
@@ -22,10 +22,9 @@
 	rownames(rrum.params) <- delta.summary[ delta.summary$partype == 0 , "item" ]
 	colnames(rrum.params) <- c( "pi" , paste( "r_", colnames(q.matrix) , sep="") )
 	for (ii in 1:I){
-		# ii <- 2
 		d.ii <- delta.summary[ delta.summary$itemno == ii , ]
 		rrum.params[ii,"pi"] <- exp( sum( d.ii$est ) )
 		rrum.params[ ii , which( q.matrix[ii,]==1) +1 ] <- exp( - d.ii$est[-1] )
-				}
+	}
 	return( rrum.params )
-        }
+}
